@@ -46,28 +46,88 @@ class BaseVisualization:
     def get_rgba_color_with_palette_id(palette_id):
         return get_rgba_color_with_palette_id(palette_id)
 
-    def draw_detections(self, img, detections, show_label, show_confidence):
-        show = self.object_drawer.draw_detections(
-            img=img,
-            detections=detections,
-            show_label=show_label,
-            show_confidence=show_confidence
-        )
-        return show
+    def draw_detections(self, img, detections,
+                        random_color=False,
+                        show_label=True,
+                        show_confidence=True):
+        """
+
+        Args:
+            img:
+            detections:
+            random_color:
+            show_label:
+            show_confidence:
+
+        Returns:
+
+        """
+        if len(detections) > 0:
+            show = self.object_drawer.draw_detections(
+                img=img,
+                detections=detections,
+                random_color=random_color,
+                show_label=show_label,
+                show_confidence=show_confidence
+            )
+            return show
+        else:
+            return img
+
+    def draw_tracking_objects(self, img, track_objs,
+                              random_color=False,
+                              show_detection=True,
+                              show_track_id=False,
+                              show_trace=True,
+                              trace_length_to_show=5
+                              ):
+        """
+
+        Args:
+            img:
+            track_objs:
+            random_color:
+            show_detection:
+            show_track_id:
+            show_trace:
+            trace_length_to_show:
+
+        Returns:
+
+        """
+        if len(track_objs) > 0:
+            show = self.object_drawer.draw_tracks(
+                img=img,
+                tracks=track_objs,
+                random_color=random_color,
+                show_detection=show_detection,
+                show_track_id=show_track_id,
+                show_trace=show_trace,
+                trace_length_to_show=trace_length_to_show
+            )
+            return show
+        else:
+            return img
 
     def draw_polygons(self, img, rois):
-        show = self.roi_drawer.draw_polygon_rois(
-            img=img,
-            rois=rois
-        )
-        return show
+        if len(rois) > 0:
+            show = self.roi_drawer.draw_polygon_rois(
+                img=img,
+                rois=rois
+            )
+            return show
+        else:
+            return img
 
     def draw_lines(self, img, lines, labels):
-        show = self.roi_drawer.draw_line_rois(
-            img=img,
-            lines=lines,
-            labels=labels)
-        return show
+        if len(lines) > 0:
+            show = self.roi_drawer.draw_line_rois(
+                img=img,
+                lines=lines,
+                labels=labels)
+            return show
+        else:
+            return img
 
     def put_text(self,
                  img,
